Attribute VB_Name = "NationalLanguage"
Option Explicit
' DERIVED FROM cwbnlcnv.h and cwbnl.h


'Added APIs from cwbNL.h
'Added VB "wrapper" functions NLAscii2Ebcdic and NLEbcdic2Ascii
'Correct error handles and return code sizes
'Altered some APIs to use array of Byte rather then string.
'Added constants from cwbnl.h


'********************************************************************'
'* Copyright = 5763-XA1 (C) Copyright IBM Corp 1994, 1995.          *'
'*  All rights reserved.                                            *'
'*  Licensed Material - Program property of IBM                     *'
'*  Refer to copyright instructions form number G120-2083.          *'
'********************************************************************'

'/*------------------------------------------------------------------*/
'/* Declare CWBNL-specific constants                                 */
'/*------------------------------------------------------------------*/

Public Const CWBNL_START = 6000

Public Const CWBNL_MAX_NAME_SIZE = 256
Public Const CWBNL_MAX_PATH_SIZE = 256
'#ifdef CWB_UNICODE
'    Public Const CWBNL_MAX_LANG_SIZE   16
'#Else
    Public Const CWBNL_MAX_LANG_SIZE = 9
'#End If

'/*------------------------------------------------------------------*/
'/* Declare code page constants                                      */
'/*------------------------------------------------------------------*/

Public Const CWBNL_CP_UNICODE_F200 = &HF200      '// UCS2 Version 1.1
Public Const CWBNL_CP_UNICODE = &H34B0          '// UCS2 Current Version
Public Const CWBNL_CP_AS400 = 1                 '// AS/400 host code page
Public Const CWBNL_CP_CLIENT_OEM = 2            '// OEM client code page
Public Const CWBNL_CP_CLIENT_ANSI = 3           '// ANSI client code page

'// CWBNL_CP_CLIENT is the generic client code page. It is defaulted
'//                 to the OEM client code page.
'#ifdef   CWB_ANSI
  Public Const CWBNL_CP_CLIENT = CWBNL_CP_CLIENT_ANSI
'#Else
'  #ifdef CWB_UNICODE
'    Public Const CWBNL_CP_CLIENT   CWBNL_CP_UNICODE
'  #Else
'    Public Const CWBNL_CP_CLIENT   CWBNL_CP_CLIENT_OEM
'  #End If
'#End If

'/*------------------------------------------------------------------*/
'/* Error messages for conversion APIs                               */
'/*------------------------------------------------------------------*/

Public Const CWBNL_ERR_CNV_UNSUPPORTED = CWBNL_START + 101
Public Const CWBNL_ERR_CNV_TBL_INVALID = CWBNL_START + 102
Public Const CWBNL_ERR_CNV_TBL_MISSING = CWBNL_START + 103
Public Const CWBNL_ERR_CNV_ERR_GET = CWBNL_START + 104
Public Const CWBNL_ERR_CNV_ERR_COMM = CWBNL_START + 105
Public Const CWBNL_ERR_CNV_ERR_SERVER = CWBNL_START + 106
Public Const CWBNL_ERR_CNV_ERR_STATUS = CWBNL_START + 107
Public Const CWBNL_ERROR_CONVERSION_INCOMPLETE_MULTIBYTE_INPUT_CHARACTER = CWBNL_START + 108
Public Const CWBNL_ERR_CNV_INVALID_SISO_STATUS = CWBNL_START + 109
Public Const CWBNL_ERR_CNV_INVALID_PAD_LENGTH = CWBNL_START + 110

'/*------------------------------------------------------------------*/
'/* Error messages for language APIs                                 */
'/*------------------------------------------------------------------*/

Public Const CWBNL_ERR_STR_TBL_INVALID = CWBNL_START + 201
Public Const CWBNL_ERR_STR_TBL_MISSING = CWBNL_START + 202
Public Const CWBNL_ERR_STR_NOT_FOUND = CWBNL_START + 203
Public Const CWBNL_ERR_NLV_NO_CONFIG = CWBNL_START + 204
Public Const CWBNL_ERR_NLV_NO_SUBDIR = CWBNL_START + 205
Public Const CWBNL_DEFAULT_HOST_CCSID_USED = CWBNL_START + 206

'/*------------------------------------------------------------------*/
'/* Error messages for locale APIs                                   */
'/*------------------------------------------------------------------*/

Public Const CWBNL_ERR_LOC_TBL_INVALID = CWBNL_START + 301
Public Const CWBNL_ERR_LOC_TBL_MISSING = CWBNL_START + 302
Public Const CWBNL_ERR_LOC_NO_CONFIG = CWBNL_START + 303
Public Const CWBNL_ERR_LOC_NO_LOCPATH = CWBNL_START + 304


'********************************************************************'
'*                                                                  *'
'* Module:                                                          *'
'*   CWBNLCNV.H                                                     *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   It contains the declarations for the following API's:          *'
'*                                                                  *'
'*     cwbNL_CCSIDToCodePage                                        *'
'*     cwbNL_CodePageToCCSID                                        *'
'*     cwbNL_Convert                                                *'
'*     cwbNL_ConvertCodePages                                       *'
'*     cwbNL_CreateConverter                                        *'
'*     cwbNL_DeleteConverter                                        *'
'*     cwbNL_GetCodePage                                            *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*   Link with the CWB.LIB import library.                          *'
'*   This module is to be used in conjunction with CWBNL.DLL.       *'
'*                                                                  *'
'********************************************************************'


'*------------------------------------------------------------------*'
'* TYPEDEFS:                                                        *'
'*------------------------------------------------------------------*'
Public cwbNL_Converter As Long
Public cwbNL_Conversion_Table As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_CCSIDToCodePage                                          *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Map CCSIDs to code pages.                                      *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   unsigned long CCSID - input                                    *'
'*     CCSID to convert to a code page.                             *'
'*                                                                  *'
'*   unsigned long * codePage - output                              *'
'*     The resulting code page.                                     *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*   CWB_INVALID_POINTER - NULL passed on output parameter.         *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbNL_CCSIDToCodePage Lib "CWBNL" (ByVal CCSID As Long, _
                                 codepage As Long, _
                                 ByVal errorHandle As Long) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_CodePageToCCSID                                          *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Map code pages to CCSIDs.                                      *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   unsigned long codePage - input                                 *'
'*     Code page to convert to a CCSID.                             *'
'*                                                                  *'
'*   unsigned long * CCSID - output                                 *'
'*     The resulting CCSID.                                         *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*   CWB_INVALID_POINTER - NULL passed on output parameter.         *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbNL_CodePageToCCSID Lib "CWBNL" ( _
                                    ByVal CCSID As Long, _
                                    codepage As Long, _
                                    ByVal errorHandle As Long) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_Convert                                                  *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Convert strings using a previously opened converter.           *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbNL_Converter theConverter                                   *'
'*     Handle to the previously opened converter.                   *'
'*                                                                  *'
'*   char * sourceBuffer - input                                    *'
'*     Buffer containing the data to convert.                       *'
'*                                                                  *'
'*   char * targetBuffer - output                                   *'
'*     Buffer to contain the converted data.                        *'
'*                                                                  *'
'*   unsigned long sourceLength - input                             *'
'*     Length of the source buffer.                                 *'
'*                                                                  *'
'*   unsigned long targetLength - input                             *'
'*     Length of the target buffer.  If converting from an ASCII    *'
'*     code page that contains DBCS characters, note that the       *'
'*     resulting data could contain shift-out and shift-in bytes.   *'
'*     Therefore the targetBuffer may need to be larger than the    *'
'*     sourceBuffer.                                                *'
'*                                                                  *'
'*   unsigned long * requiredLen - output                           *'
'*     Actual length of the result.  If requiredLen > resultLen,    *'
'*     the return value will be CWB_BUFFER_OVERFLOW.                *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*   CWB_INVALID_POINTER - NULL passed on output parameter.         *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
'Array of Byte version
Declare Function cwbNL_Convert Lib "CWBNL" ( _
                        ByVal theConverter As Long, _
                        ByVal sourceLength As Long, _
                        ByVal targetLength As Long, _
                        sourceBuffer As Byte, _
                        targetBuffer As Byte, _
                        numberOfErrors As Long, _
                        firstErrorIndex As Long, _
                        requiredLen As Long, _
                        ByVal errorHandle As Long) As Long
'String version
Declare Function cwbNL_ConvertS Lib "CWBNL" Alias "cwbNL_Convert" ( _
                        ByVal theConverter As Long, _
                        ByVal sourceLength As Long, _
                        ByVal targetLength As Long, _
                        ByVal sourceBuffer As String, _
                        ByVal targetBuffer As String, _
                        numberOfErrors As Long, _
                        firstErrorIndex As Long, _
                        requiredLen As Long, _
                        ByVal errorHandle As Long) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_ConvertCodePages                                         *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Convert strings from one code page to another.  This API       *'
'*   combines the three converter APIs for the default conversion.  *'
'*     cwbNL_CreateConverter                                        *'
'*     cwbNL_Convert                                                *'
'*     cwbNL_DeleteConverter                                        *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   unsigned long sourceCodePage - input                           *'
'*     Code page of the data in the source buffer.                  *'
'*                                                                  *'
'*   unsigned long targetCodePage - input                           *'
'*     Code page to which the data should be converted.             *'
'*                                                                  *'
'*   char * sourceBuffer - input                                    *'
'*     Buffer containing the data to convert.                       *'
'*                                                                  *'
'*   char * targetBuffer - output                                   *'
'*     Buffer to contain the converted data.                        *'
'*                                                                  *'
'*   unsigned long sourceLength - input.                            *'
'*     Length of the source buffer                                  *'
'*                                                                  *'
'*   unsigned long targetLength - input.                            *'
'*     Length of the target buffer                                  *'
'*                                                                  *'
'*   unsigned long * requiredLen - output                           *'
'*     Actual length of the result.  If requiredLen > resultLen,    *'
'*     the return value will be CWB_BUFFER_OVERFLOW.                *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*   CWB_INVALID_POINTER - NULL passed on output parameter.         *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbNL_ConvertCodePages Lib "CWBNL" ( _
                        ByVal sourceCodePage As Long, _
                        ByVal targetCodePage As Long, _
                        ByVal sourceLength As Long, _
                        ByVal targetLength As Long, _
                        sourceBuffer As Byte, _
                        targetBuffer As Byte, _
                        numberOfErrors As Long, _
                        positionOfFirstError As Long, _
                        requiredLen As Long, _
                        ByVal errorHandle As Long) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_CreateConverter                                          *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Create a cwbNL_Converter to be used on subsequent calls to     *'
'*   cwbNL_Convert().                                               *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   unsigned long sourceCodePage - input                           *'
'*     Code page of the source data.                                *'
'*                                                                  *'
'*   unsigned long targetCodePage - input                           *'
'*     Code page to which the data should be converted.             *'
'*                                                                  *'
'*   cwbNL_Converter * theConverter - output                        *'
'*     The newly created converter.                                 *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'*   unsigned long shiftInShiftOutStatus - input                    *'
'*     Indicates whether the shift-in and shift-out bytes are part  *'
'*     of the input or output data.                                 *'
'*     0 - False, no shift-in and shift-out bytes are part          *'
'*         of the data string.                                      *'
'*     1 - True, shift-in and shift-out characters are part of the  *'
'*         data string.                                             *'
'*                                                                  *'
'*   unsigned long padLength - input                                *'
'*     Length of pad characters.                                    *'
'*     0 - No pad characters for this conversion request            *'
'*     1 - 1 byte of pad character. This is valid for only if       *'
'*         the target code page is either SBCS or DBCS code page    *'
'*     2 - 2 bytes of pad characters. This is valid only if the     *'
'*         code page is not a single-byte code page.                *'
'*                                                                  *'
'*   char * pad - input                                             *'
'*     The character or characters for padding.                     *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*   CWB_INVALID_POINTER - NULL passed on output parameter.         *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*   Instead of calling cwbNL_ConvertCodePages multiple times with  *'
'*   the same code pages:                                           *'
'*                                                                  *'
'*     cwbNL_ConvertCodePages(850, 500, ...);                       *'
'*     cwbNL_ConvertCodePages(850, 500, ...);                       *'
'*     cwbNL_ConvertCodePages(850, 500, ...);                       *'
'*                                                                  *'
'*   It is more efficient to create a converter and use it          *'
'*   multiple times:                                                *'
'*                                                                  *'
'*     cwbNL_CreateConverter(850, 500, &conv, ...);                 *'
'*     cwbNL_Convert(conv, ...);                                    *'
'*     cwbNL_Convert(conv, ...);                                    *'
'*     cwbNL_Convert(conv, ...);                                    *'
'*     cwbNL_DeleteConverter(conv, ...);                            *'
'*                                                                  *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbNL_CreateConverter Lib "CWBNL" ( _
                                 ByVal sourceCodePage As Long, _
                                 ByVal targetCodePage As Long, _
                                 theConverter As Long, _
                                 ByVal errorHandle As Long, _
                                 ByVal shiftInShiftOutStatus As Long, _
                                 ByVal padLength As Long, _
                                 ByVal pad As String) As Long
                 
'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_DeleteConverter                                          *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Delete a cwbNL_Converter.                                      *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbNL_Converter theConverter - input                           *'
'*     A previously created converter.                              *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbNL_DeleteConverter Lib "CWBNL" (ByVal theConverter As Long, _
                               ByVal errorHandle As Long) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_GetCodePage                                              *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Get the code page of the current process.                      *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   unsigned long * codePage - output                              *'
'*     Code page of the current process.                            *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*   CWB_INVALID_POINTER - NULL passed on output parameter.         *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbNL_GetCodePage Lib "CWBNL" (codepage As Long, _
                                             ByVal errorHandle As Long _
                                             ) As Long
'*********************************************************************
'       APIs from cwbNL.h
'*********************************************************************
'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbNL_GetLang                                                  */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Get the current language setting.                              */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   const char * mriBasePath - input                               */
'/*     Pointer to the mriBasePath.                                  */
'/*     e.g. C:\Program Files\IBM\ClientAccess/400                   */
'/*     If NULL, the mriBasePath of the ClinetAccess/400 product is  */
'/*     used.                                                        */
'/*                                                                  */
'/*   char * resultPtr - output                                      */
'/*     Pointer to the buffer to contain the result.                 */
'/*                                                                  */
'/*   unsigned short resultLen - input                               */
'/*     Length of the result buffer.                                 */
'/*     Recommended size is CWBNL_MAX_LANG_SIZE.                     */
'/*                                                                  */
'/*   unsigned short * requiredLen - output                          */
'/*     Actual length of the result.  If requiredLen > resultLen,    */
'/*     the return value will be CWB_BUFFER_OVERFLOW.                */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*     Any returned messages will be written to this object.        */
'/*     It is created with the cwbSV_CreateErrHandle() API.          */
'/*     The messages may be retrieved through the cwbSV_GetErrText() */
'/*     API.  If the parameter is set to zero, no messages will be   */
'/*     retrievable.                                                 */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_BUFFER_OVERFLOW - Buffer too small to contain result.      */
'/*   CWB_NON_REPRESENTABLE_UNICODE_CHAR - One or more input UNICODE */
'/*                                        characters have no        */
'/*                                        representation in the     */
'/*                                        codepage being used.      */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   The result buffer will contain the name of the language        */
'/*   subdirectory.  This language subdirectory contains the         */
'/*   language-specific files.  This language subdirectory name      */
'/*   can also be passed to cwbNL_GetLangName.                       */
'/*                                                                  */
'/********************************************************************/

'unsigned int CWB_ENTRY cwbNL_GetLang(
'                             const char     *mriBasePath,
'                             char           *resultPtr,
'                             unsigned short  resultLen,
'                             unsigned short *requiredLen,
'                             cwbSV_ErrHandle errorHandle);
Declare Function cwbNL_GetLang Lib "CWBNL" ( _
                                    ByVal mriBasePath As String, _
                                    ByRef resultPtr As Byte, _
                                    ByVal resultLen As Integer, _
                                    requiredLen As Integer, _
                                    ByVal errorHandle As Long _
                                    ) As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbNL_SaveLang                                                 */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Save the language setting in the product registry.             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   const char * lang - input                                      */
'/*     Address of the ASCIIZ string representing the language.      */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*     Any returned messages will be written to this object.        */
'/*     It is created with the cwbSV_CreateErrHandle() API.          */
'/*     The messages may be retrieved through the cwbSV_GetErrText() */
'/*     API.  If the parameter is set to zero, no messages will be   */
'/*     retrievable.                                                 */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_NON_REPRESENTABLE_UNICODE_CHAR - One or more input UNICODE */
'/*                                        characters have no        */
'/*                                        representation in the     */
'/*                                        codepage being used.      */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   The language must be a value returned from one of these APIs:  */
'/*     cwbNL_GetLang                                                */
'/*     cwbNL_FindFirstLang                                          */
'/*     cwbNL_FindNextLang                                           */
'/*                                                                  */
'/*   The following APIs are affected by this call:                  */
'/*     cwbNL_GetLang                                                */
'/*     cwbNL_GetLangPath                                            */
'/*                                                                  */
'/********************************************************************/
'#if !( defined(CWB_ANSI_ONLY) || defined(CWB_UNICODE_ONLY) )
'unsigned int CWB_ENTRY cwbNL_SaveLang(
'                             const char      *lang,
'                             cwbSV_ErrHandle  errorHandle);
Declare Function cwbNL_SaveLang Lib "CWBNL" ( _
                                    ByVal lang As String, _
                                    ByVal errorHandle As Long _
                                    ) As Long
'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbNL_GetLangName                                              */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Return the descriptive name of a language setting.             */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   const char * lang - input                                      */
'/*     Address of the ASCIIZ string representing the language.      */
'/*                                                                  */
'/*   char * resultPtr - output                                      */
'/*     Pointer to the buffer to contain the result.                 */
'/*                                                                  */
'/*   unsigned short resultLen - input                               */
'/*     Length of the result buffer.                                 */
'/*     Recommended size is CWBNL_MAX_NAME_SIZE.                     */
'/*                                                                  */
'/*   unsigned short * requiredLen - output                          */
'/*     Actual length of the result.  If requiredLen > resultLen,    */
'/*     the return value will be CWB_BUFFER_OVERFLOW.                */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*     Any returned messages will be written to this object.        */
'/*     It is created with the cwbSV_CreateErrHandle() API.          */
'/*     The messages may be retrieved through the cwbSV_GetErrText() */
'/*     API.  If the parameter is set to zero, no messages will be   */
'/*     retrievable.                                                 */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_NON_REPRESENTABLE_UNICODE_CHAR - One or more input UNICODE */
'/*                                        characters have no        */
'/*                                        representation in the     */
'/*                                        codepage being used.      */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   The language must be a value returned from one of these APIs:  */
'/*     cwbNL_GetLang                                                */
'/*     cwbNL_FindFirstLang                                          */
'/*     cwbNL_FindNextLang                                           */
'/*                                                                  */
'/********************************************************************/
'#if !( defined(CWB_ANSI_ONLY) || defined(CWB_UNICODE_ONLY) )
'unsigned int CWB_ENTRY cwbNL_GetLangName(
'                             const char     *lang,
'                             char           *resultPtr,
'                             unsigned short  resultLen,
'                             unsigned short *requiredLen,
'                             cwbSV_ErrHandle errorHandle);
Declare Function cwbNL_GetLangName Lib "CWBNL" ( _
                                 ByVal lang As String, _
                                 ByRef resultPtr As Byte, _
                                 ByVal resultLen As Integer, _
                                 requiredLen As Integer, _
                                 ByVal errorHandle As Long _
                                 ) As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbNL_GetLangPath                                              */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Return the complete path for language files.                   */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   const char * mriBasePath - input                               */
'/*     Pointer to the mriBasePath.                                  */
'/*     e.g. C:\Program Files\IBM\ClientAccess/400                   */
'/*     If NULL, the mriBasePath of the ClinetAccess/400 product is  */
'/*     used.                                                        */
'/*                                                                  */
'/*   char * resultPtr - output                                      */
'/*     Pointer to the buffer to contain the result.                 */
'/*                                                                  */
'/*   unsigned short resultLen - input                               */
'/*     Length of the result buffer.                                 */
'/*     Recommended size is CWBNL_MAX_PATH_SIZE.                     */
'/*                                                                  */
'/*   unsigned short * requiredLen - output                          */
'/*     Actual length of the result.  If requiredLen > resultLen,    */
'/*     the return value will be CWB_BUFFER_OVERFLOW.                */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*     Any returned messages will be written to this object.        */
'/*     It is created with the cwbSV_CreateErrHandle() API.          */
'/*     The messages may be retrieved through the cwbSV_GetErrText() */
'/*     API.  If the parameter is set to zero, no messages will be   */
'/*     retrievable.                                                 */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_PATH_NOT_FOUND - Path not found.                           */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_NON_REPRESENTABLE_UNICODE_CHAR - One or more input UNICODE */
'/*                                        characters have no        */
'/*                                        representation in the     */
'/*                                        codepage being used.      */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   The result buffer will contain the complete path of the        */
'/*   language subdirectory.  Language files should be loaded from   */
'/*   this path.                                                     */
'/*                                                                  */
'/********************************************************************/
'unsigned int CWB_ENTRY cwbNL_GetLangPath(
'                             const char      *mriBasePath,
'                             char            *resultPtr,
'                             unsigned short   resultLen,
'                             unsigned short  *requiredLen,
'                             cwbSV_ErrHandle  errorHandle);

Declare Function cwbNL_GetLangPath Lib "CWBNL" ( _
                                 ByVal mriBasePath As String, _
                                 ByRef resultPtr As Byte, _
                                 ByVal resultLen As Integer, _
                                 requiredLen As Integer, _
                                 ByVal errorHandle As Long _
                                 ) As Long
                             
'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbNL_FindFirstLang                                            */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the first available language.                          */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   const char * mriBasePath - input                               */
'/*     Pointer to the mriBasePath.                                  */
'/*     e.g. C:\Program Files\IBM\ClientAccess/400                   */
'/*     If NULL, the mriBasePath of the ClinetAccess/400 product is  */
'/*     used.                                                        */
'/*                                                                  */
'/*   char * resultPtr - output                                      */
'/*     Pointer to the buffer to contain the result.                 */
'/*                                                                  */
'/*   unsigned short resultLen - input                               */
'/*     Length of the result buffer.                                 */
'/*     Recommended size is CWBNL_MAX_LANG_SIZE.                     */
'/*                                                                  */
'/*   unsigned short * requiredLen - output                          */
'/*     Actual length of the result.  If requiredLen > resultLen,    */
'/*     the return value will be CWB_BUFFER_OVERFLOW.                */
'/*                                                                  */
'/*   unsigned long * searchHandle - output                          */
'/*     Search handle to be passed on subsequent calls to            */
'/*     cwbNL_FindNextLang.                                          */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*     Any returned messages will be written to this object.        */
'/*     It is created with the cwbSV_CreateErrHandle() API.          */
'/*     The messages may be retrieved through the cwbSV_GetErrText() */
'/*     API.  If the parameter is set to zero, no messages will be   */
'/*     retrievable.                                                 */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_FILE_NOT_FOUND - File not found.                           */
'/*   CWB_PATH_NOT_FOUND - Path not found.                           */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_NON_REPRESENTABLE_UNICODE_CHAR - One or more input UNICODE */
'/*                                        characters have no        */
'/*                                        representation in the     */
'/*                                        codepage being used.      */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   The result buffer will contain a language.                     */
'/*                                                                  */
'/********************************************************************/
'#if !( defined(CWB_ANSI_ONLY) || defined(CWB_UNICODE_ONLY) )
'unsigned int CWB_ENTRY cwbNL_FindFirstLang(
'                             const char      *mriBasePath,
'                             char            *resultPtr,
'                             unsigned short   resultLen,
'                             unsigned short  *requiredLen,
'                             unsigned long   *searchHandle,
'                             cwbSV_ErrHandle  errorHandle);
Declare Function cwbNL_FindFirstLang Lib "CWBNL" ( _
                                 ByVal mriBasePath As String, _
                                 ByRef resultPtr As Byte, _
                                 ByVal resultLen As Integer, _
                                 requiredLen As Integer, _
                                 searchHandle As Long, _
                                 ByVal errorHandle As Long _
                                 ) As Long

'/********************************************************************/
'/*                                                                  */
'/* API:                                                             */
'/*   cwbNL_FindNextLang                                             */
'/*                                                                  */
'/* Purpose:                                                         */
'/*   Returns the next available language.                           */
'/*                                                                  */
'/* Parameters:                                                      */
'/*   char * resultPtr - output                                      */
'/*     Pointer to the buffer to contain the result.                 */
'/*                                                                  */
'/*   unsigned short resultLen - input                               */
'/*     Length of the result buffer.                                 */
'/*     Recommended size is CWBNL_MAX_LANG_SIZE.                     */
'/*                                                                  */
'/*   unsigned short * requiredLen - output                          */
'/*     Actual length of the result.  If requiredLen > resultLen,    */
'/*     the return value will be CWB_BUFFER_OVERFLOW.                */
'/*                                                                  */
'/*   unsigned long * searchHandle - output                          */
'/*     Search handle to be passed on subsequent calls to            */
'/*     cwbNL_FindNextLang.                                          */
'/*                                                                  */
'/*   cwbSV_ErrHandle errorHandle - input                            */
'/*     Any returned messages will be written to this object.        */
'/*     It is created with the cwbSV_CreateErrHandle() API.          */
'/*     The messages may be retrieved through the cwbSV_GetErrText() */
'/*     API.  If the parameter is set to zero, no messages will be   */
'/*     retrievable.                                                 */
'/*                                                                  */
'/* Return Codes:                                                    */
'/*   The following list shows common return values.                 */
'/*                                                                  */
'/*   CWB_OK - Successful completion.                                */
'/*   CWB_INVALID_HANDLE - Invalid handle.                           */
'/*   CWB_INVALID_POINTER - NULL passed on output parameter.         */
'/*   CWB_NO_MORE_FILES - No more files are found.                   */
'/*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory; may have failed   */
'/*                           to allocate temporary buffer.          */
'/*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. */
'/*   CWB_API_ERROR - General API failure.                           */
'/*                                                                  */
'/* Usage Notes:                                                     */
'/*   The result buffer will contain a language.                     */
'/*                                                                  */
'/********************************************************************/
'#if !( defined(CWB_ANSI_ONLY) || defined(CWB_UNICODE_ONLY) )
'unsigned int CWB_ENTRY cwbNL_FindNextLang(
'                             char            *resultPtr,
'                             unsigned short   resultLen,
'                             unsigned short  *requiredLen,
'                             unsigned long   *searchHandle,
'                             cwbSV_ErrHandle  errorHandle);
Declare Function cwbNL_FindNextLang Lib "CWBNL" ( _
                                 ByRef resultPtr As Byte, _
                                 ByVal resultLen As Integer, _
                                 requiredLen As Integer, _
                                 searchHandle As Long, _
                                 ByVal errorHandle As Long _
                                 ) As Long

Public Function NLAscii2Ebcdic(sAsciiIn As String, abEbcdicOut() As Byte) As Long
'EBCDIC Strings should be stored in an Array of byte to avoid any potential mangling
'by Visual Basics UNICODE to ANSI coversion done on API calls.  (VB stores strings
'internally as unicode).  For best performance when performing multiple conversion
'you would want to use CreateConverter, cwbNL_Convert, cwbNL_DeleteConverter
'instead.  Run the CreateConverter only once and reuse the handle.
'
'Assumes Input and Output are sized to desired value.
'

Dim rc As Long
Dim lSrcLen As Long
Dim lTargetLen As Long
Dim lNumErrors As Long
Dim lPos1stErr As Long
Dim lReqLen As Long
Dim hcwbErr As Long
Dim abData() As Byte

Dim sErrText As String
Dim S As String
Dim lErrCount As Long

   'Set up source
   lSrcLen = Len(sAsciiIn)
   ReDim abData(lSrcLen - 1) As Byte
   rc = String2Byte(sAsciiIn, abData)
   'ViewByteArray abData
   
   lTargetLen = Sizeof(abEbcdicOut)
   
   '//create the error msg handle
   rc = cwbSV_CreateErrHandle(hcwbErr)

   rc = cwbNL_ConvertCodePages(CWBNL_CP_CLIENT_ANSI, CWBNL_CP_AS400, _
                              lSrcLen, _
                              lTargetLen, _
                              abData(0), _
                              abEbcdicOut(0), _
                              lNumErrors, _
                              lPos1stErr, _
                              lReqLen, _
                              hcwbErr)
                              
                              
   If (rc <> 0) Then GoTo NLAscii2EbcdicErr
   'Call ViewByteArray(abEbcdicOut)
   
   Call cwbSV_DeleteErrHandle(hcwbErr)
   NLAscii2Ebcdic = rc
   Exit Function
   
NLAscii2EbcdicErr:
   Dim ErrRc As Long
   '//query error object here
   sErrText = "rc " & Str(rc) & " with Err text:"
   S = Space(512)
   ErrRc = cwbSV_GetErrCount(hcwbErr, _
                           lErrCount)
   If lErrCount >= 1 Then
      ErrRc = cwbSV_GetErrTextA(hcwbErr, _
                        S, _
                        Len(S), _
                        0)
      sErrText = sErrText & S
      MsgBox sErrText, , gAppName
   Else
      MsgBox "rc " & Str(rc) & vbCrLf & _
             "Number of Errors in String: " & Str(lNumErrors) & vbCrLf & _
             "Position of First Error: " & Str(lPos1stErr) & vbCrLf _
             , , gAppName
   End If
   
   Call cwbSV_DeleteErrHandle(hcwbErr)
   NLAscii2Ebcdic = rc

End Function
Public Function NLEbcdic2Ascii(abEbcdicIn() As Byte, sAsciiOut As String, _
                                Optional lEbcdicDataLen As Long) As Long
'Make sure the byte array does not have an unwanted null on the end (vb will append
'a null to the string on an API call)

Dim rc As Long
Dim lSrcLen As Long
Dim lTargetLen As Long
Dim lNumErrors As Long
Dim lPos1stErr As Long
Dim lReqLen As Long
Dim hcwbErr As Long
Dim abData() As Byte

Dim sErrText As String
Dim S As String
Dim lErrCount As Long

   If lEbcdicDataLen = 0 Then
      lEbcdicDataLen = Sizeof(abEbcdicIn)
   End If
   lTargetLen = Len(sAsciiOut)
   ReDim abData(lTargetLen - 1) As Byte
   
   '//create the error msg handle
   rc = cwbSV_CreateErrHandle(hcwbErr)

   rc = cwbNL_ConvertCodePages(CWBNL_CP_AS400, CWBNL_CP_CLIENT_ANSI, _
                              lEbcdicDataLen, _
                              lTargetLen, _
                              abEbcdicIn(0), _
                              abData(0), _
                              lNumErrors, _
                              lPos1stErr, _
                              lReqLen, _
                              hcwbErr)
                              
                              
   If (rc <> 0) Then GoTo NLEbcdic2AsciiErr
   'Call ViewByteArray(abData)
   Call Byte2String(abData, sAsciiOut)
   
   rc = cwbSV_DeleteErrHandle(hcwbErr)
   NLEbcdic2Ascii = rc
   Exit Function
   
NLEbcdic2AsciiErr:
   Dim ErrRc As Long
   '//query error object here
   sErrText = "rc " & Str(rc) & " with Err text:"
   S = Space(512)
   ErrRc = cwbSV_GetErrCount(hcwbErr, _
                           lErrCount)
   If lErrCount >= 1 Then
      ErrRc = cwbSV_GetErrTextA(hcwbErr, _
                        S, _
                        Len(S), _
                        0)
      sErrText = sErrText & S
      MsgBox sErrText, , gAppName
   Else
      MsgBox "rc " & Str(rc) & vbCrLf & _
             "Number of Errors in String: " & Str(lNumErrors) & vbCrLf & _
             "Position of First Error: " & Str(lPos1stErr) & vbCrLf _
             , , gAppName
   End If
   
   Call cwbSV_DeleteErrHandle(hcwbErr)
   NLEbcdic2Ascii = rc

End Function


