Attribute VB_Name = "RemoteCommand"
Option Explicit

' NOTE: String data types are only used for input parameters that are
'       standard ANSI character strings (such as system name,
'       library name, etc).
'       Array of Byte data types are used for any output or input
'       output parameters, as well as input parameters that may
'       pass hex data (non-standard ansi characters).

'********************************************************************'
'* Copyright = 5763-XA1 (C) Copyright IBM Corp 1994, 1995.          *'
'*  All rights reserved.                                            *'
'*  Licensed Material - Program property of IBM                     *'
'*  Refer to copyright instructions form number G120-2083.          *'
'********************************************************************'
'********************************************************************'
'*                                                                  *'
'* Module:                                                          *'
'*   CWBRC.h                                                        *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   The functions listed in this file can be used to run commands  *'
'*   or call programs on the AS/400 system.  They can be used to    *'
'*   access any AS/400 command or program, including AS/400 APIs.   *'
'*                                                                  *'
'*   The APIs can be broken down into three groups:                 *'
'*                                                                  *'
'*   The following APIs can be used to access the remote command    *'
'*   server program on the AS/400 system.  The system handle is     *'
'*   used to run commands and call programs:                        *'
'*     cwbRC_StartSys()                                             *'
'*     cwbRC_GetClientCCSID()                                       *'
'*     cwbRC_GetHostCCSID()                                         *'
'*     cwbRC_GetSysName()                                           *'
'*     cwbRC_StopSys()                                              *'
'*                                                                  *'
'*   The following API will run an AS/400 command:                  *'
'*     cwbRC_RunCmd()                                               *'
'*                                                                  *'
'*   The following APIs can be used to access programs and their    *'
'*   parameters:                                                    *'
'*     cwbRC_CreatePgm()                                            *'
'*     cwbRC_AddParm()                                              *'
'*     cwbRC_CallPgm()                                              *'
'*     cwbRC_GetParmCount()                                         *'
'*     cwbRC_GetParm()                                              *'
'*     cwbRC_GetPgmName()                                           *'
'*     cwbRC_GetLibName()                                           *'
'*     cwbRC_SetParm()                                              *'
'*     cwbRC_SetPgmName()                                           *'
'*     cwbRC_SetLibName()                                           *'
'*     cwbRC_DeletePgm()                                            *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*   Link with CWB.LIB import library.                              *'
'*   This module is to be used in conjunction with CWBRC.DLL.       *'
'*                                                                  *'
'********************************************************************'

'*------------------------------------------------------------------*'
'* TYPEDEFS:                                                        *'
'*------------------------------------------------------------------*'

'*------------------------------------------------------------------*'
'*                                                                  *'
'* Definitions for parameter types                                  *'
'*                                                                  *'
'*------------------------------------------------------------------*'
Public Const CWBRC_INPUT = 1
Public Const CWBRC_OUTPUT = 2
Public Const CWBRC_INOUT = 3

'*-------------------------------------------------------------------*'
'* Component RC errors based on CWB_LAST (in CWB.H)                  *'
'*-------------------------------------------------------------------*'
Public Const CWBRC_START = CWB_LAST + 1

'*------------------------------------------------------------------*'
'* Invalid system handle                                            *'
'*------------------------------------------------------------------*'
Public Const CWBRC_INVALID_SYSTEM_HANDLE = CWBRC_START

'*------------------------------------------------------------------*'
'* Invalid program handle                                           *'
'*------------------------------------------------------------------*'
Public Const CWBRC_INVALID_PROGRAM = CWBRC_START + 1

'*------------------------------------------------------------------*'
'* System name is too long or cannot be converted                   *'
'*------------------------------------------------------------------*'
Public Const CWBRC_SYSTEM_NAME = CWBRC_START + 2

'*------------------------------------------------------------------*'
'* Command string is too long or cannot be converted                *'
'*------------------------------------------------------------------*'
Public Const CWBRC_COMMAND_STRING = CWBRC_START + 3

'*------------------------------------------------------------------*'
'* program name is too long or cannot be converted                  *'
'*------------------------------------------------------------------*'
Public Const CWBRC_PROGRAM_NAME = CWBRC_START + 4

'*------------------------------------------------------------------*'
'* Library name is too long or cannot be converted                  *'
'*------------------------------------------------------------------*'
Public Const CWBRC_LIBRARY_NAME = CWBRC_START + 5

'*------------------------------------------------------------------*'
'* Invalid parameter type specified                                 *'
'*------------------------------------------------------------------*'
Public Const CWBRC_INVALID_TYPE = CWBRC_START + 6

'*------------------------------------------------------------------*'
'* Invalid parameter length                                         *'
'*------------------------------------------------------------------*'
Public Const CWBRC_INVALID_PARM_LENGTH = CWBRC_START + 7

'*------------------------------------------------------------------*'
'* Invalid parameter specified                                      *'
'*------------------------------------------------------------------*'
Public Const CWBRC_INVALID_PARM = CWBRC_START + 8

'*------------------------------------------------------------------*'
'* Attempt to add more than 25 paramters to a program               *'
'*------------------------------------------------------------------*'
Public Const CWBRC_TOO_MANY_PARMS = CWBRC_START + 9

'*------------------------------------------------------------------*'
'* Index is out of range for this program                           *'
'*------------------------------------------------------------------*'
Public Const CWBRC_INDEX_RANGE_ERROR = CWBRC_START + 10

'*------------------------------------------------------------------*'
'* Command rejected by user exit program                            *'
'*------------------------------------------------------------------*'
Public Const CWBRC_REJECTED_USER_EXIT = CWBRC_START + 11

'*------------------------------------------------------------------*'
'* Error in user exit program                                       *'
'*------------------------------------------------------------------*'
Public Const CWBRC_USER_EXIT_ERROR = CWBRC_START + 12

'*------------------------------------------------------------------*'
'* Command failed                                                   *'
'*------------------------------------------------------------------*'
Public Const CWBRC_COMMAND_FAILED = CWBRC_START + 13

'*------------------------------------------------------------------*'
'* Program not found or could not be accessed                       *'
'*------------------------------------------------------------------*'
Public Const CWBRC_PROGRAM_NOT_FOUND = CWBRC_START + 14

'*------------------------------------------------------------------*'
'* Error occurred when calling the program                          *'
'*------------------------------------------------------------------*'
Public Const CWBRC_PROGRAM_ERROR = CWBRC_START + 15

'*------------------------------------------------------------------*'
'* Command string is longer than the maximum of 6000 characters     *'
'*------------------------------------------------------------------*'
Public Const CWBRC_COMMAND_TOO_LONG = CWBRC_START + 16

'*------------------------------------------------------------------*'
'* Unexpected error                                                 *'
'*------------------------------------------------------------------*'
Public Const CWBRC_UNEXPECTED_ERROR = CWBRC_START + 99

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_AddParm                                                  *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Add a parameter to the program that is identified by the       *'
'*   handle.  This function should be called once for each          *'
'*   parameter that is to be added to the program.  When the        *'
'*   program is called the parameters will be in the same order     *'
'*   that they are added using this function.                       *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_PgmHandle program - input                                *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_CreatePgm API.  It identifies the program object.      *'
'*                                                                  *'
'*   unsigned short type - input                                    *'
'*     The type of parameter this is.  Use one of the defined       *'
'*     parameter types: CWBRC_INPUT, CWBRC_OUTPUT, CWBRC_INOUT.     *'
'*                                                                  *'
'*   unsigned long length - input                                   *'
'*     The length of the parameter.  If this is an CWBRC_OUTPUT     *'
'*     parameter, the length should be the length of the buffer     *'
'*     where the returned parameter will be written.                *'
'*                                                                  *'
'*   unsigned char * parameter - input                              *'
'*     Pointer to a buffer that will contain:  the value if the     *'
'*     type is CWBRC_INPUT or CWBRC_INOUT or the place where the    *'
'*     returned parameter is to be written if the type is           *'
'*     CWBRC_OUTPUT or CWBRC_INOUT.                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWBRC_INVALID_PROGRAM - Invalid program handle.                *'
'*   CWBRC_INVALID_TYPE - Invalid type specified.                   *'
'*   CWBRC_INVALID_PARM_LENGTH - Invalid parameter length.          *'
'*   CWBRC_INVALID_PARM - Invalid parameter.                        *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*   Parameter data is assumed to be binary.  No conversion will    *'
'*   be performed on the parameter data.                            *'
'*                                                                  *'
'********************************************************************'

'Defined parameter as byte because VB moves string outside programmer's control
Declare Function cwbRC_AddParm Lib "CWBRC" ( _
                                       ByVal program As Long, _
                                       ByVal typeParameter As Integer, _
                                       ByVal Length As Long, _
                                       parameter As Byte) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_CallPgm                                                  *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Calls the program identified by the handle.  The return code   *'
'*   will indicate the success or failure of the program.           *'
'*   Additional messages can be returned by using the message       *'
'*   handle that is returned.                                       *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_SysHandle system - input                                 *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_StartSys function.  It identifies the AS/400           *'
'*     system.                                                      *'
'*                                                                  *'
'*   cwbRC_PgmHandle program - input                                *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_CreatePgm API.  It identifies the program object.      *'
'*     object.                                                      *'
'*                                                                  *'
'*   cwbSV_ErrHandle msgHandle - output                             *'
'*     Any returned messages will be written to this object.  It    *'
'*     is created with the cwbSV_CreateErrHandle API.  The          *'
'*     messages may be retrieved through the cwbSV_GetErrTextIndexed*'
'*     API.  If the parameter is set to zero, no messages will be   *'
'*     retrieved.                                                   *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_COMMUNICATIONS_ERROR - A communications error occurred.    *'
'*   CWBRC_INVALID_SYSTEM_HANDLE - Invalid system handle.           *'
'*   CWBRC_INVALID_PROGRAM - Invalid program handle.                *'
'*   CWBRC_REJECTED_USER_EXIT - Command rejected by user exit       *'
'*                              program.                            *'
'*   CWBRC_USER_EXIT_ERROR - Error in user exit program.            *'
'*   CWBRC_PROGRAM_NOT_FOUND - Program not found.                   *'
'*   CWBRC_PROGRAM_ERROR - Error when calling program.              *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_CallPgm Lib "CWBRC" ( _
                                    ByVal system As Long, _
                                    ByVal program As Long, _
                                    ByVal msgHandle As Long) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_CreatePgm                                                *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   This function creates a program object given a program and     *'
'*   library name.  The handle that is returned can be used to      *'
'*   add parameters to the program and then call the program.       *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   char * programName - input                                     *'
'*     Pointer to an ASCIIZ string that contains the name of the    *'
'*     program that you want to call.                               *'
'*                                                                  *'
'*   char * libraryName - input                                     *'
'*     Pointer to an ASCIIZ string that contains the name of the    *'
'*     library where the program resides.                           *'
'*                                                                  *'
'*   cwbRC_PgmHandle * program - output                             *'
'*     Pointer to a cwbRC_PgmHandle where the handle of the         *'
'*     program will be returned.                                    *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_POINTER - Bad or NULL pointer.                     *'
'*   CWBRC_PROGRAM_NAME - Program name is too long.                 *'
'*   CWBRC_LIBRARY_NAME - Library name is too long.                 *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*   You should create a separate program object for each program   *'
'*   you want to call on the AS/400.  You can use the functions     *'
'*   described in this file to change the vaules of the parameters  *'
'*   being sent to the program, but cannot change the number of     *'
'*   parameters being sent.                                         *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_CreatePgm Lib "CWBRC" (ByVal programName As String, _
                                             ByVal libraryName As String, _
                                             program As Long) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_DeletePgm                                                *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   This function deletes the program object that is identified    *'
'*   by the handle provided.                                        *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_PgmHandle program - input                                *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_CreatePgm API.  It identifies the program object.      *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWBRC_INVALID_PROGRAM - Invalid program handle.                *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_DeletePgm Lib "CWBRC" (ByVal program As Long) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_GetClientCCSID                                           *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Get the coded character set identifier (CCSID) associated with *'
'*   the current process.  This CCSID along with the host CCSID can *'
'*   be used to convert EBCDIC data returned by some AS/400 programs*'
'*   to ASCII data that can be used in client applications.         *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_SysHandle system - input                                 *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_StartSys function.  It identifies the AS/400           *'
'*     system.                                                      *'
'*                                                                  *'
'*   unsigned long * clientCCSID - output                           *'
'*     Pointer to an unsigned long where the client CCSID will be   *'
'*     written.                                                     *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_POINTER - Bad or NULL pointer.                     *'
'*   CWBRC_INVALID_SYSTEM_HANDLE - Invalid system handle.           *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*   See related APIs in the CWBNLCNV.H file.                       *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_GetClientCCSID Lib "CWBRC" (ByVal system As Long, _
                                       clientCCSID As Long) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_GetHostCCSID                                             *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Get the coded character set identifier (CCSID) associated with *'
'*   the AS/400 server job.  This CCSID along with the client CCSID *'
'*   can be used to convert EBCDIC data returned by some AS/400     *'
'*   programs to ASCII data that can be used in client applications.*'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_SysHandle system - input                                 *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_StartSys function.  It identifies the AS/400           *'
'*     system.                                                      *'
'*                                                                  *'
'*   unsigned long * hostCCSID - output                             *'
'*     Pointer to an unsigned long where the host CCSID will be     *'
'*     written.                                                     *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_POINTER - Bad or NULL pointer.                     *'
'*   CWBRC_INVALID_SYSTEM_HANDLE - Invalid system handle.           *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*   See related APIs in the CWBNLCNV.H file.                       *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_GetHostCCSID Lib "CWBRC" (ByVal system As Long, _
                                                hostCCSID As Long) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_GetLibName                                               *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Get the name of the library that was used when creating this   *'
'*   program object.                                                *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_PgmHandle program - input                                *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_CreatePgm API.  It identifies the program object.      *'
'*                                                                  *'
'*   char * libraryName - output                                    *'
'*     Pointer to a ten character buffer where the name of the      *'
'*     library will be written.                                     *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_POINTER - Bad or NULL pointer.                     *'
'*   CWBRC_INVALID_PROGRAM - Invalid program handle.                *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_GetLibNameS Lib "CWBRC" (ByVal program As Long, _
                                    ByVal libraryName As String) As Long

Declare Function cwbRC_GetLibName Lib "CWBRC" (ByVal program As Long, _
                                    ByRef libraryName As Byte) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_GetParm                                                  *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Retrieve the parameter identified by the index.  The index     *'
'*   will range from 0 to the total number of parameters - 1.  This *'
'*   number can be obtained by calling the cwbRC_GetParmCount       *'
'*   API.                                                           *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_PgmHandle handle - input                                 *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_CreatePgm API.  It identifies the program object.      *'
'*                                                                  *'
'*   unsigned short index - input                                   *'
'*     The number of the specific parameter in this program that    *'
'*     should be retrieved.  This index is zero based.              *'
'*                                                                  *'
'*   unsigned short * type - output                                 *'
'*     Pointer to the type of parameter this is.  The value will be *'
'*     one of the defined parameter types: CWBRC_INPUT,             *'
'*     CWBRC_OUTPUT, CWBRC_INOUT.                                   *'
'*                                                                  *'
'*   unsigned long * length - input                                 *'
'*     Pointer to the length of the parameter.                      *'
'*                                                                  *'
'*   unsigned char * * parameter - output                           *'
'*     Pointer to a buffer that will contain the address of the     *'
'*     actual parameter.                                            *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_POINTER - Bad or NULL pointer.                     *'
'*   CWBRC_INVALID_PROGRAM - Invalid program handle.                *'
'*   CWBRC_INDEX_RANGE_ERROR - Index is out of range.               *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
'This doesn't have much use in vb
Declare Function cwbRC_GetParm Lib "CWBRC" (ByVal program As Long, _
                                    ByVal index As Integer, _
                                    typeParameter As Integer, _
                                    Length As Long, _
                                    parameterAddr As Long) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_GetParmCount                                             *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Get the number of parameters for this program object.          *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_PgmHandle handle - input                                 *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_CreatePgm API.  It identifies the program object.      *'
'*                                                                  *'
'*   unsigned short * count - output                                *'
'*     Pointer to an unsigned short where the parameter count will  *'
'*     be written.                                                  *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_POINTER - Bad or NULL pointer.                     *'
'*   CWBRC_INVALID_PROGRAM - Invalid program handle.                *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_GetParmCount Lib "CWBRC" (ByVal program As Long, _
                                          count As Integer) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_GetPgmName                                               *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Get the name of the program that was used when creating this   *'
'*   program.                                                       *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_PgmHandle program - input                                *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_CreatePgm API.  It identifies the program object.      *'
'*                                                                  *'
'*   char * programName - output                                    *'
'*     Pointer to a ten character buffer where the name of the      *'
'*     program will be written.                                     *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_POINTER - Bad or NULL pointer.                     *'
'*   CWBRC_INVALID_PROGRAM - Invalid program handle.                *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_GetPgmNameS Lib "CWBRC" (ByVal program As Long, _
                                    ByVal programName As String) As Long
                                    
Declare Function cwbRC_GetPgmName Lib "CWBRC" (ByVal program As Long, _
                                    programName As Byte) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_GetSysName                                               *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Get the name of the system that was used when starting this    *'
'*   system.                                                        *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_SysHandle system - input                                 *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_StartSys function.  It identifies the AS/400           *'
'*     system.                                                      *'
'*                                                                  *'
'*   char * systemName - output                                     *'
'*     Pointer to an 8 character buffer where the name of the       *'
'*     system will be written.                                      *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_POINTER - Bad or NULL pointer.                     *'
'*   CWBRC_INVALID_SYSTEM_HANDLE - Invalid system handle.           *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_GetSysNameS Lib "CWBRC" (ByVal system As Long, _
                              ByVal systemName As String) As Long
                              
Declare Function cwbRC_GetSysName Lib "CWBRC" (ByVal system As Long, _
                              systemName As Byte) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_RunCmd                                                   *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Issues the command on the system identified by the handle.     *'
'*   The return code will indicate success or failure of the        *'
'*   command.  Additional messages can be returned by using the     *'
'*   message handle that is returned.                               *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_SysHandle system - input                                 *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_StartSys function.  It identifies the AS/400           *'
'*     system.                                                      *'
'*                                                                  *'
'*   char * commandString - input                                   *'
'*     Pointer to a string that contains the command to be issued   *'
'*     on the AS/400 system.  This is an ASCIIZ string.             *'
'*                                                                  *'
'*   cwbSV_ErrHandle msgHandle - output                             *'
'*     Any messages returned from the AS/400 will be written to     *'
'*     this object.  It is created with the cwbSV_CreateErrHandle   *'
'*     API.  The messages may be retrieved through the              *'
'*     cwbSV_GetErrTextIndexed API.  If the parameter is set to     *'
'*     zero, no messages will be retrieved.                         *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_COMMUNICATIONS_ERROR - A communications error occurred.    *'
'*   CWB_INVALID_POINTER - Bad or NULL pointer.                     *'
'*   CWBRC_INVALID_SYSTEM_HANDLE - Invalid system handle.           *'
'*   CWBRC_REJECTED_USER_EXIT - Command rejected by user exit       *'
'*                              program.                            *'
'*   CWBRC_USR_EXIT_ERROR - Error in user exit program.             *'
'*   CWBRC_COMMAND_FAILED - Command failed.                         *'
'*   CWBRC_COMMAND_TOO_LONG - Command string is too long.           *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_RunCmd Lib "CWBRC" (ByVal system As Long, _
                                    ByVal commandString As String, _
                                    ByVal msgHandle As Long) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_SetLibName                                               *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Set the name of the library for this program object.           *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_PgmHandle program - input                                *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_CreatePgm API.  It identifies the program object.      *'
'*                                                                  *'
'*   char * libraryName - input                                     *'
'*     Pointer to an ASCIIZ string that contains the name of the    *'
'*     library where the program resides.                           *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWBRC_INVALID_PROGRAM - Invalid program handle.                *'
'*   CWBRC_LIBRARY_NAME - Library name is too long.                 *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*   Use this function to change the name of the name of the library*'
'*   that contains the program you want to call.  This function     *'
'*   should not be used to call a different program with different  *'
'*   parameters.                                                    *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_SetLibName Lib "CWBRC" (ByVal program As Long, _
                                 ByVal libraryName As String) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_SetParm                                                  *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Set the parameter value identified by the index.  The index    *'
'*   will range from 0 to the total number of parameters - 1.  This *'
'*   number can be obtained by calling the cwbRC_GetParmCount       *'
'*   API.  Note that this function is to be used to change a        *'
'*   parameter.  Use cwbRC_AddParm to create the parameter.         *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_PgmHandle handle - input                                 *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_CreatePgm API.  It identifies the program object.      *'
'*                                                                  *'
'*   unsigned short index - input                                   *'
'*     The number of the specific parameter in this program that    *'
'*     should be changed.  This index is zero based.                *'
'*                                                                  *'
'*   unsigned short type - input                                    *'
'*     The type of parameter this is.  Use one of the defined       *'
'*     parameter types: CWBRC_INPUT, CWBRC_OUTPUT, CWBRC_INOUT.     *'
'*                                                                  *'
'*   unsigned long length - input                                   *'
'*     The length of the parameter.  If this is an CWBRC_OUT        *'
'*     parameter, the length should be the length of the buffer     *'
'*     where the returned parameter will be written.                *'
'*                                                                  *'
'*   unsigned char * parameter - input                              *'
'*     Pointer to a buffer that will contain:  the value if the     *'
'*     type is CWBRC_INPUT or CWBRC_INOUT or the place where the    *'
'*     return parameter is to be written if the type is             *'
'*     CWBRC_OUTPUT or CWBRC_INOUT.                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWBRC_INVALID_PROGRAM - Invalid program handle.                *'
'*   CWBRC_INVALID_TYPE - Invalid type specified.                   *'
'*   CWBRC_INVALID_PARM_LENGTH - Invalid parameter length.          *'
'*   CWBRC_INVALID_PARM - Invalid parameter.                        *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*   Parameter data is assumed to be binary.  No conversion will    *'
'*   be performed on the parameter data.                            *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_SetParm Lib "CWBRC" (ByVal program As Long, _
                                    ByVal index As Integer, _
                                    ByVal typeParameter As Integer, _
                                    ByVal Length As Integer, _
                                    parameter As Byte) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_SetPgmName                                               *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Set the name of the program for this program object.           *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_PgmHandle program - input                                *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_CreatePgm API.  It identifies the program object.      *'
'*                                                                  *'
'*   char * programName - input                                     *'
'*     Pointer to an ASCIIZ string that contains the name of the    *'
'*     program that you want to call.                               *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWBRC_INVALID_PROGRAM - Invalid program handle.                *'
'*   CWBRC_PROGRAM_NAME - Program name is too long.                 *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*   Use this function to change the name of the name of the program*'
'*   that you want to call.  Use this function to change the name of*'
'*   the program.  This function should not be used to change the   *'
'*   program object to call a different program with different      *'
'*   parameters.                                                    *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_SetPgmName Lib "CWBRC" (ByVal program As Long, _
                                 ByVal programName As String) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_StartSys                                                 *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   This function starts a conversation with the specified system. *'
'*   If the conversation is successfully started, a handle is       *'
'*   returned.  Use this handle with all subsequent calls to        *'
'*   issue commands or call programs.  When the conversation is     *'
'*   no longer needed, use the handle with the API,                 *'
'*   cwbRC_StopSys to end the conversation.                         *'
'*   The cwbRC_StartSys API may be called multiple times within an  *'
'*   application.  If the application name is set to NULL, a new    *'
'*   conversation is started each time the API is called.  If the   *'
'*   application name is set, the same system handle is returned    *'
'*   each time this function is called.                             *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   char * systemName - input                                      *'
'*           Pointer to an ASCIIZ string that contains the name     *'
'*           of the system that you want programs and commands      *'
'*           to be executed on.                                     *'
'*                                                                  *'
'*   char * appName - input                                         *'
'*           Pointer to an ASCIIZ string of no more than 12         *'
'*           characters.  This uniquely identifies the application  *'
'*           that will share a single conversation for running.     *'
'*           commands and calling programs.                         *'
'*                                                                  *'
'*   cwbRC_SysHandle * system - output                              *'
'*           Pointer to a cwbRC_SysHandle where the handle of       *'
'*           the system will be returned.                           *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_COMMUNICATIONS_ERROR - A communications error occurred.    *'
'*   CWB_SERVER_PROGRAM_NOT_FOUND - AS/400 application not found.   *'
'*   CWB_HOST_NOT_FOUND - AS/400 system inactive or does not exist. *'
'*   CWB_SECURITY_ERROR - A security error has occurred.            *'
'*   CWB_LICENSE_ERROR - A license error has occurred.              *'
'*   CWB_CONFIG_ERROR - A configuration error has occurred.         *'
'*   CWBRC_SYSTEM_NAME - System name is too long.                   *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*   The application name will typically be set to NULL unless you  *'
'*   have a specific need to share a conversation between several   *'
'*   threads within the same process.                               *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_StartSys Lib "CWBRC" (ByVal systemName As String, _
                                             ByVal appName As String, _
                                             system As Long) As Long

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbRC_StopSys                                                  *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   This function stops a conversation with the system specified   *'
'*   by the handle.  This handle can no longer be used to issue     *'
'*   program calls or commands.                                     *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbRC_SysHandle system - input                                 *'
'*     Handle that was returned by a previous call to the           *'
'*     cwbRC_StartSys function.  It identifies the AS/400           *'
'*     system.                                                      *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWBRC_INVALID_SYSTEM_HANDLE - Invalid system handle.           *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbRC_StopSys Lib "CWBRC" (ByVal system As Long) As Long


