Attribute VB_Name = "vbcwbco"
'*********************************************************************
'/* COPYRIGHTS:                                                      */
'/*                                                                  */
'/*   This module contains code made available by IBM Corporation on */
'/* an AS IS basis.  Any one receiving the module is  considered  to */
'/* be  licensed under IBM copyrights to use the IBM-provided source */
'/* code in any way he or  she  deems  fit,  including  copying  it, */
'/* compiling  it,  modifying  it,  and  redistributing  it, with or */
'/* without modifications.  No license  under  any  IBM  patents  or */
'/* patent  applications  is  to  be  implied  from  this  copyright */
'/* license.                                                         */
'/*                                                                  */
'/*   A user of the module should understand that IBM cannot provide */
'/* technical support for the module and will not be responsible for */
'/* any consequences of use of the program.                          */
'/*                                                                  */
'/*   Any notice,  including this one, are not to  be  removed  from */
'/* the module with out the prior written consent of IBM.            */
'/*                                                                  */
'*********************************************************************


'******************************************************************
'Visual Basic cwbco api wrapper over C api's
'APIs implemented
'  cwbCO_GetUserID
'  cwbCO_GetDefaultSysName
'  cwbCO_GetActiveConversations
'  cwbCO_GetHostVersion
'
'Dependencies:
'     Uses the CA/400 system list box
'     Bytehelp.bas - string/byte array conversion and viewing
'     cwb.bas     - basic CA/400 API defines (cwb.h)
'     cwbco.bas   - cwbCO CA/400 API defines  (cwbco.h)
'******************************************************************
Option Explicit
Public Function GetUserID(szSysName As String, lUserID_Type As Long, _
                           Optional rcOut As Variant) _
                           As String
'***********************************************************************
'Retrieve either current userid or default user id for given system name
'
'INPUT:
'  szSysName      -  System name
'  lUserID_Type   -  Type of user id to return
'                    CWBCO_DEFAULT_USER_ID - Default userid for system
'                    CWBCO_CURRENT_USER_ID - Current userid for system
'OUTPUT:
'  rc (optional)  -  API rc
'  Userid         -  Null if error
'DEPENDENCIES:
'     Byte2String in ByteHelp.bas
'     cwbco.bas for API declare and constant defines
'***********************************************************************
   '//GetUserID
   Dim lUserIDLen As Long
   Dim cUserID(11) As Byte

   '//Common
   Dim rc As Long
   Dim S As String
   
   rc = String2Byte("          ", cUserID)      'init userid to blanks
   lUserIDLen = UBound(cUserID)                 'userid length
   
   'Call the api
   rc = cwbCO_GetUserID(szSysName, _
                        cUserID(0), _
                        lUserID_Type, _
                        lUserIDLen)
   If (rc = 0) Then
      S = Space(UBound(cUserID))          'Size the string
      Call Byte2String(cUserID, S)        'convert
      S = Left(S, lUserIDLen - 1)         'Trim to actual size w/o null
      GetUserID = S
   Else
      'MsgBox "GetUserID failed with rc: " & Str(rc), , gAppName
      'txtUserID.Text = "** Error: rc = " & Str(rc)
      GetUserID = ""
   End If
   rcOut = rc
   
End Function



Public Function GetHostVersion(sSysName As String, _
                                 Optional rc As Variant) _
                                 As String
'***********************************************************************
'Retrieve the version and release of the host system and return
'it as a string formated as VxRx.
'
'INPUT:
'  sSysName - System to query
'OUTPUT:
'  rc (optional)  -  API rc
'  string         -  Null if error, formated as VxRx
'DEPENDENCIES:
'     Byte2String in ByteHelp.bas
'     cwbco.bas for API declare and constant defines
'***********************************************************************
   Dim lVersion As Long
   Dim lRelease As Long

   '//Common
   Dim S As String
      
   'Call the api
   rc = cwbCO_GetHostVersion(sSysName, _
                              lVersion, _
                              lRelease)
   If (rc = 0) Then
      GetHostVersion = "V" & Trim(Str(lVersion)) _
                     & "R" & Trim(Str(lRelease))
   Else
      GetHostVersion = ""
   End If
   
End Function
Public Function GetActiveConversations(sSysName As String) As Long
'***********************************************************************
'Retrieve the number of active conversations.  See API reference
'for details. 0 is returned if not connected, any error, invalid sys name
'etc - no rc.
'
'INPUT:
'  sSysName - System to query
'OUTPUT:
'  long         -  0 if error, # active conversations
'DEPENDENCIES:
'     cwbco.bas for API declare and constant defines
'***********************************************************************
      
   'Call the api
   GetActiveConversations = cwbCO_GetActiveConversations(sSysName)
   
End Function


Public Function GetDefaultSysName(Optional rc As Variant) _
                                    As String
'***********************************************************************
'Retrieve the name of the default system for Client Access
'
'INPUT:
'OUTPUT:
'  rc (optional)  -  API rc
'  SystemName     -  Null if error
'DEPENDENCIES:
'     Byte2String in ByteHelp.bas
'     cwbco.bas for API declare and constant defines
'***********************************************************************
   Dim cSysName(9) As Byte
   Dim lLenSysName As Long
   Dim lNeeded As Long

   '//Common
   'Dim rc As Long
   Dim S As String
   
   lLenSysName = UBound(cSysName)               'userid length
   
   'Call the api
   rc = cwbCO_GetDefaultSysName(cSysName(0), _
                                lLenSysName, _
                                lNeeded, _
                                0)
   If (rc = 0) Then
      S = Space(UBound(cSysName))         'Size the string
      Call Byte2String(cSysName, S)       'convert
      S = Left(S, lNeeded - 1)            'Trim to actual size w/o null
      GetDefaultSysName = S
   Else
      'MsgBox "GetUserID failed with rc: " & Str(rc), , gAppName
      'txtUserID.Text = "** Error: rc = " & Str(rc)
      GetDefaultSysName = ""
   End If
   
End Function



